# Design your first empennage {#design-your-first-empennage}
Let's dive into the fun part. In this guide we will create an empennage for a classic tube and wing configuration with a conventional empennage design method.

  - [Requirements:](#requirements) - Information on tool requirements
  - [Design parameters:](#design-parameters) - Information on design parameters
  - [Tool execution:](#tool-execution) - Tool execution information
  - [Reporting](#reporting) - Wing Design tool report information
  - [Changing parameters](#changing-parameters) - The fun part! Let's change parameters
  - [Troubleshooting](#troubleshooting) - Something went wrong? Maybe you are not the first one!

The empennage will be part of a generic tube and wing aircraft which is a look-a-like A320.

The wing will be part of a generic tube and wing aircraft which is a look-a-like A320.

## Requirements
Therefor we use an _Aircraft Exchange File_ where the tools _initial\_sizing_ and _fuselage\_design_ already run.

From the _Aircraft Exchange File_ we have the following information:

From the Requirements block:
Parameter            |         Value
:--------------------|-------------:
A/C Type             |         CeraS
A/C Model            |      SMR-2020
Configuration Type   | Tube and Wing
Empennage definition |  conventional

From _initial\_sizing_ tool

Parameter    |           Value
:------------|---------------:
MTOM         |        64232 kg
Wing loading | 619.8444 kg/m^2

Wing Parameters (excerpt):

Parameter | Value
:----|----:
Ref. Area | 103.63
Span  | 32.67
Aspect Ratio | 10.30
Taper Ratio | 0.17
Quarter-Chord Sweep | 27°
Dihedral | 5°

<dl class="section todo">
<dt>Note</dt>
<dd>Parameters of the fuselage arenot listed - however, it has a length of ~37m and a width of ~4m.</dd>
</dl>
 
## Design parameters
Empennage Design tool parameters for conventional low method

_Design and mass mode_
Parameter     |                    Value
:-------------|------------------------:
`design_mode` | `mode_0` &rarr; `design`
`mass_mode`   |  `mode_0` &rarr; `flops`

_Tail Element `ID = 0`_
Parameter | Value
:-- | --:
`name` | `vertical_stabilizer`
`rear_x_offset`| `1.5m`
`centerline_y_offset` | `0.0m`
`centerline_z_offset` | `0.0m`
`volume_coefficient` | `0.0` &rarr; `automatic determination`
`factor_aspect_ratio`| `0.2`
`factor_taper_ratio`| `1.56`
`delta_sweep` | `12°`
`profiles` | `((n0012),(n0012))`
`spars` | `((front_spar,0.0,0.2,0.2, 1.0,0.2,0.2),(rear_spar,0.0,0.6,0.6,1.0,0.6,0.6) `
`control_devices` | `((rudder, -25°, 25°,0.2,0.7,1.0,0.9,0.7,1.0))`

_Tail Element `ID = 1`_
Parameter | Value
:-- | --:
`name` | `horizontal_stabilizer`
`rear_x_offset`| `1.0m`
`centerline_y_offset` | `0.0m`
`centerline_z_offset` | `0.0m`
`volume_coefficient` | `0.0` &rarr; `automatic determination`
`factor_aspect_ratio`| `0.53`
`factor_taper_ratio`| `1.66`
`delta_sweep` | `5°`
`profiles` | `((n0012),(n0012))`
`spars` | `((front_spar,0.0,0.2,0.2, 1.0,0.2,0.2),(rear_spar,0.0,0.6,0.6,1.0,0.6,0.6) `
`control_devices` | `((elevator, -25°, 25°,0.2,0.7,1.0,0.9,0.7,1.0))`

## Tool execution
The tool can be executed from console directly if all paths are set (see [How to run a tool](howToRunATool.md)).

We go through the tool output step by step
```
*******************************************************************************
25.11.2024 16:23:36 - Start empennage_design
25.11.2024 16:23:36 - [MODULE RUNTIMEINFO] - empennage_design
25.11.2024 16:23:36 -    [CONSOLE  ] - [ON]
25.11.2024 16:23:36 -    [LOG      ] - [ON]
25.11.2024 16:23:36 -    [PLOT     ] - [OFF]
25.11.2024 16:23:36 -       [COPY  ] - [ON]
25.11.2024 16:23:36 -       [DELETE] - [ON]
25.11.2024 16:23:36 -    [REPORT   ] - [ON]
25.11.2024 16:23:36 -    [TEX      ] - [OFF]
25.11.2024 16:23:36 -    [INFOFILES] - [OFF]
25.11.2024 16:23:36 -    [GNUPLOT]
25.11.2024 16:23:36 -       [PATH    ] -
25.11.2024 16:23:36 -       [FILENAME] - DEFAULT
25.11.2024 16:23:36 -    [INKSCAPE]
25.11.2024 16:23:36 -       [PATH    ] -
25.11.2024 16:23:36 -       [FILENAME] - DEFAULT
25.11.2024 16:23:36 -    [LOGFILE]
25.11.2024 16:23:36 -       [PATH    ] -
25.11.2024 16:23:36 -       [FILENAME] - empennage_design.log
25.11.2024 16:23:36 -    [IO/ACXML]
25.11.2024 16:23:36 -       [PATH    ] - ../projects
25.11.2024 16:23:36 -       [FILENAME] - csmr-2020.xml
25.11.2024 16:23:36 -    [MODCONFIG]
25.11.2024 16:23:36 -       [PATH    ] - .
25.11.2024 16:23:36 -       [FILENAME] - empennage_design_conf.xml
25.11.2024 16:23:36 - Checking directory... [REPORT]
25.11.2024 16:23:36 - Checking directory... [TEX]
25.11.2024 16:23:36 - Checking directory... [HTML]
25.11.2024 16:23:36 - Checking directory... [LOGFILES]
```
To this point, the module is in the top level stage and creates folders and checks the configuration file settings from the control block. Here you can see some common information.
```
25.11.2024 16:23:36 - Initializing empennage
25.11.2024 16:23:36 - Empennage type -> conventional tail (vertical_stabilizer/horizontal_stabilizer)
25.11.2024 16:23:36 - Checking directory... [AIRFOILDATA]
25.11.2024 16:23:36 - Running empennage -> conventional tail
25.11.2024 16:23:36 - Mode active -> Design
25.11.2024 16:23:36 - Empennage position (x y z) -> 30.4154 0 0.924292
```
Afterwards the module progresses and starts with the empennage design. It tells you what empennage type will be designed and which mode is used. Also the position and will be shown (most forward point of the empennage). Afterwards the mass information is given:
```
25.11.2024 16:23:36 - Mode active -> Mass computation - FLOPS
25.11.2024 16:23:36 - Vertical stabilizer mass ... 393.37855570692426
25.11.2024 16:23:36 - Horizontal stabilizer mass ... 502.10
25.11.2024 16:23:36 - Empennage mass ... 895.4748333992579
25.11.2024 16:23:36 - Empennage cog  ... 34.55, 0.00, 3.05
```

It ends with updating and writing the report
```
25.11.2024 16:23:36 - Updating empennage -> conventional tail
25.11.2024 16:23:36 - Reporting empennage -> conventional tail
25.11.2024 16:23:40 - CSS code written to style.css successfully.
25.11.2024 16:23:40 - Finish empennage_design
```

Let's have a look at it.
## Reporting
The HTML report is splitted - on the left half, one can see numerical information of the empennage design. The right side contains plots and visual information.

![Report Page](figures/Report_page_empennage_design.png)

It starts with general information for the vertical stabilizer by section parameters. Then you get information on spars and control devices. It concludes with mass information.

The plot side starts with a general wing planfrom view, followed by the airfoil shape and the thickness and twist distribution


## Changing parameters
Lets change a parameter for the vertical stabilizer &rarr; we reduce the rudder chord length to only 10% of the chord length.

The resulted output in the console will not change, however you see that the rudder area is quite small:

![Report Page after change](figures/Report_page_empennage_design_change.png)

Soo .... Now it is your turn!

<dl class="section invariant">
<dt>Tip</dt>
<dd>Start by changing only one parameter at once. There might be interactions with other parameters, so don't rush!</dd>
</dl>

## Troubleshooting
- Tool does not run properly:
  - Make sure you have all the paths set up correctly and the specified elements exist!
- Tool is not there:
  - You can build the tool directly from scratch - see therefor [How to build a tool](howToBuildATool.md)


