# Run your first tank design
Let's dive into the fun part and design some tanks!

## Tool single execution
The tool can be executed from the console directly if all paths are set. The following will happen:

- [Console output](#console-output)
- [Generation of reports and plots](#reporting)
- [Writing output to aircraft exchange file](#acxml)

Some of the above mentioned steps did not work? Check out the [troubleshooting](#troubleshooting) section for advices.
Also, if you need some additional information on the underlying methodology, check out the page on the [tank design method](tank_design_method.md).

So, feel free to open the terminal and run `tank_design.exe` to see what happens...

### Console output {#console-output}
Firstly, you see output in the console window. Let's go through it step by step...

```
2024-12-10 13:05:44,866 - PRINT - Tank design started...
2024-12-10 13:05:45,829 - PRINT - Valid tank configuration found in acXML: wing_with_additional_center_and_trim_tank
```
To this point, the module started, found a valid tank configuration in the _acXML_, and prints the name of the configuration for your information.

```
2024-12-10 12:26:26,090 - PRINT - Initial sizing loop! Energy demand is estimated (3.35 liters per PAX per 100 km).
```
If the tool is executed during the initial sizing loop in the workflow, or when no information on the required mission energy is available from the _mission\_analysis_ tool, the energy demand is estimated.

```
2024-12-10 13:05:45,844 - PRINT - Wing tank design started...
2024-12-10 13:05:45,846 - PRINT - Vent tank (located near each wing tip) calculated.
```
Afterwards, the tank design starts with the wing tanks, specifically with the vent tank dimensioning that is based on the overall wing tank volume.

```
2024-12-10 13:05:45,846 - PRINT - Inner left wing tank (tank_0) calculated. Volume (energy) available: 4,800.69 L (155,182.15 MJ)
2024-12-10 13:05:45,846 - PRINT - Outer left wing tank (tank_1) calculated. Volume (energy) available: 4,630.29 L (149,674.22 MJ)
2024-12-10 13:05:45,847 - PRINT - Inner right wing tank (tank_2) calculated. Volume (energy) available: 4,800.69 L (155,182.15 MJ)
2024-12-10 13:05:45,847 - PRINT - Outer right wing tank (tank_3) calculated. Volume (energy) available: 4,630.29 L (149,674.22 MJ)
2024-12-10 13:05:45,847 - PRINT - Wing center tank (tank_4) calculated. Volume (energy) available: 7,646.16 L (247,162.02 MJ)
2024-12-10 13:05:45,847 - PRINT - Wing tanks successfully calculated.
```
The tool continues with the calculation of the wing tank entities - in this example the inner and outer left and right wing tanks, and the wing center tank. Additionally, information is given on the volume and energy available of each tank.

```
2024-12-10 13:05:45,847 - PRINT - Energy check: Wing center tank necessary to store required energy amount.
2024-12-10 13:05:45,847 - PRINT - Energy check: Energy demand covered.
```
After the wing tank design there is an energy check to review whether the required mission energy can be stored in the tanks. If the energy demand would not be covered up until this point, an energy check would be carried out after the calculation of every subsequent tank.

```
2024-12-10 13:05:45,848 - PRINT - Additional center tank design started...
2024-12-10 13:05:45,848 - PRINT - Additional center tank (tank_5) calculated. Volume (energy) available: 3,068.50 L (103,818.10 MJ)
2024-12-10 13:05:45,849 - PRINT - Additional center tank design completed.
2024-12-10 13:05:45,849 - PRINT - Additional center tank is generated but unnecessary to store required energy amount.
```
As already known, there is an additional center tank given in the _acXML_ tank configuration that is calculated subsequently. Furthermore, the information is given that this tank is not necessary to store the required mission energy amount.

```
2024-12-10 13:05:45,850 - PRINT - Trim tank design started...
2024-12-10 13:05:45,850 - PRINT - Trim tank (tank_6) calculated. Volume (energy) available: 2,679.94 L (86,629.04 MJ)
2024-12-10 13:05:45,850 - PRINT - Trim tank design completed.
2024-12-10 13:05:45,850 - PRINT - Trim tank is generated but unnecessary to store required energy amount.
2024-12-10 13:05:45,851 - PRINT - Tank design successful.
2024-12-10 13:05:45,851 - PRINT - Debug: The "calculate_tanks" function was successfully executed.
2024-12-10 13:05:45,851 - PRINT - Tank design completed.
```
The trim tank is then dimensioned and the tank design is completed.

```
2024-12-10 13:05:48,050 - WARNING - Warning: No "method_plot" function in "methodplot.py" file implemented yet.
2024-12-10 13:05:48,050 - WARNING - Warning: No "method_html_report" function in "methodhtmlreport.py" file implemented yet.
2024-12-10 13:05:48,055 - PRINT - Method-specific data are written to 'tank_design_results.xml'...
2024-12-10 13:05:48,212 - WARNING - Warning: No "method_tex_output" function in "methodtexoutput.py" file implemented yet.
2024-12-10 13:05:48,213 - PRINT - Tank design finished.
```
Finally, you receive information about the reports and plots created (depending on your settings) and the tool is successfully completed.

### Reporting {#reporting}
In the following, a short overview is given on the generated reports:

- A `tank_design.log` file is written within the directory of the executable
- Depending on your settings, the following output is generated and saved in the `reporting` folder, located in the directory of the aircraft exchange file:
    - an HTML report in the `report_html` folder
    - a TeX report in the `report_tex` folder (not implemented yet)
    - an XML file with additional output data in the `report_xml` folder (currently, only a rough output file is generated with the routing information but without any additional data)
    - plots in the `plots` folder (not implemented yet)

### Write data to the aircraft exchange file {#acxml}
!!! note 
    The _acXML_ is an exchange file - we agreed on that only data will be saved as output that is needed by another tool!

Results are saved in the aircraft exchange file at the `/aircraft_exchange_file/component_design/tank`. node. The following information is written to the _acXML_:
```plaintext
Aircraft exchange file
|- Component design
|  |- Tank
|  |  |- Position*
|  |  |- Mass properties**
|  |  |- Specific
|  |  |  |- Additional fuselage length
|  |  |  |- Tank (ID="0")
|  |  |  |  |- Name
|  |  |  |  |- Designator
|  |  |  |  |- Position*
|  |  |  |  |- Direction*
|  |  |  |  |- Mass properties**
|  |  |  |  |- Maximum energy capacity
|  |  |  |  |- Energy capacity required for mission
|  |  |  |  |- Geometry
|  |  |  |  |  |- Cross section (ID="0")
|  |  |  |  |  |  |- Name
|  |  |  |  |  |  |- Position*
|  |  |  |  |  |  |- Shape
|  |  |  |  |  |  |- Height
|  |  |  |  |  |  |- Width
|  |  |  |  |  |  |- Length
|  |  |  |  |  |- Cross section (ID="1")
|  |  |  |  |  |  |- ...
|  |  |  |- Tank (ID="1")
|  |  |  |  |- ...
```

<sup>*</sup> Node has been shortened. It contains the following sub-nodes: x, y, z

<sup>*</sup> Node has been shortened. It contains sub-nodes with information on the mass, inertia, and center of gravity.

## Troubleshooting {#troubleshooting}
- The tool does not run properly? *Make sure you have all the paths set up correctly and the specified elements exist.*
